@@ -153,15 +153,20 @@ sub task_run {
 
     my $project  = shift or confess "usage: task_run(*project,task,parameters)";
     my $tid      = shift or confess "usage: task_run(project,*task,parameters)";
+    my @args     = @_; 
 
     my @parameters;
 
     my $verbose_mode=0;
+
+    my $no_exec_mode=0;
+
     my $cron_mode=0;
 
-    for my $i (@ARGV){
-      $verbose_mode=1, next if $i eq '--verbose';
-      $cron_mode=1, next if $i eq '--cron';
+    for my $i (@args){
+      $verbose_mode=1,  next if $i eq '--verbose';
+      $cron_mode=1,     next if $i eq '--cron';
+      $no_exec_mode=1,  next if $i eq '--no-exec';
       push @parameters, $i;
     }
 
@@ -195,7 +200,7 @@ sub task_run {
 
     if ($cron_mode) {
         $cmd.=" $parameters";
-        my $repo_file = sparrow_root.'/reports/report-'.$project.'-'.$tid.'-'.$$.'.txt';
+        my $repo_file = sparrow_root.'/cache/report-'.$project.'-'.$tid.'-'.$$.'.txt';
         exec "( $cmd 1>$repo_file 2>\&1 && rm $repo_file  )  || ( cat $repo_file ; rm -v $repo_file; exit 1; )";
     } else {
 
@@ -205,8 +210,11 @@ sub task_run {
           print map {"# $_\n"} split /&&\s+/, $cmd;
           print "\n";
         }
-
-        exec $cmd;
+        if ($no_exec_mode){
+          execute_shell_command($cmd);
+        } else {
+          exec $cmd
+        }
     }
 
 }
